targeted_overlay library

Classes

AxisMirrors
Defines whether the overlay should be mirrored along vertical and/or horizontal axis based on the attach point.

Enums

AttachPoint
Defines the point on the target widget where the overlay will be attached. For example, AttachPoint.topRight will attach the overlay to the top-right corner of the target widget.

Mixins

TargetedOverlayMixin
Mixin that provides functionality to manage overlays attached to target widgets. The mixin allows inserting, hiding, and clearing overlays based on target widgets identified by GlobalKeys. It also provides methods to register target widgets and update their positions.

Typedefs

OverlayBuilder = Widget Function(void remove())
Signature for building overlay widgets.